<?php
/**
 * Magazine Express functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Magazine Express
 */

include get_theme_file_path( 'vendor/wptrt/autoload/src/Magazine_Express_Loader.php' );

$magazine_express_loader = new \WPTRT\Autoload\Magazine_Express_Loader();

$magazine_express_loader->magazine_express_add( 'WPTRT\\Customize\\Section', get_theme_file_path( 'vendor/wptrt/customize-section-button/src' ) );

$magazine_express_loader->magazine_express_register();

if ( ! function_exists( 'magazine_express_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function magazine_express_setup() {

		add_theme_support( 'responsive-embeds' );

		add_theme_support( 'woocommerce' );
		
		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

        add_image_size('magazine-express-featured-header-image', 2000, 660, true);

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus( array(
            'primary' => esc_html__( 'Primary','magazine-express' ),
	        'footer'=> esc_html__( 'Footer Menu','magazine-express' ),
        ) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'magazine_express_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 50,
			'width'       => 50,
			'flex-width'  => true,
		) );

		add_editor_style( array( '/editor-style.css' ) );

		add_theme_support( 'wp-block-styles' );

		add_theme_support( 'align-wide' );
	}
endif;
add_action( 'after_setup_theme', 'magazine_express_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function magazine_express_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'magazine_express_content_width', 1170 );
}
add_action( 'after_setup_theme', 'magazine_express_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function magazine_express_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'magazine-express' ),
		'id'            => 'sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'magazine-express' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );
}
add_action( 'widgets_init', 'magazine_express_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function magazine_express_scripts() {

	wp_enqueue_style('magazine-express-font', magazine_express_font_url(), array());

	wp_enqueue_style( 'magazine-express-block-editor-style', get_theme_file_uri('/assets/css/block-editor-style.css') );

	// load bootstrap css
    wp_enqueue_style( 'flatly-css', esc_url(get_template_directory_uri()) . '/assets/css/flatly.css');

	wp_enqueue_style( 'magazine-express-style', get_stylesheet_uri() );
	wp_style_add_data('magazine-express-style', 'rtl', 'replace');

	// fontawesome
	wp_enqueue_style( 'fontawesome-style', esc_url(get_template_directory_uri()).'/assets/css/fontawesome/css/all.css' );

	wp_enqueue_style( 'owl.carousel-style', esc_url(get_template_directory_uri()).'/assets/css/owl.carousel.css' );

    wp_enqueue_script('owl.carousel-js', esc_url(get_template_directory_uri()) . '/assets/js/owl.carousel.js', array('jquery'), '', true );

    wp_enqueue_script('magazine-express-theme-js', esc_url(get_template_directory_uri()) . '/assets/js/theme-script.js', array('jquery'), '', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'magazine_express_scripts' );

/**
 * Enqueue theme color style.
 */
function magazine_express_theme_color() {

    $theme_color_css = '';
    $magazine_express_theme_color_one = get_theme_mod('magazine_express_theme_color_one');
    $magazine_express_theme_color_two = get_theme_mod('magazine_express_theme_color_two');

	$theme_color_css = '
		.top-info, .menu-header, #featured-topic,#colophon,.serach_inner,.pro-button a:hover, .woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover, .woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover{
			background: '.esc_attr($magazine_express_theme_color_one).';
		}
		{
			color: '.esc_attr($magazine_express_theme_color_one).';
		}
		.wp-block-quote, .wp-block-quote:not(.is-large):not(.is-style-large), .wp-block-pullquote{
			border-color: '.esc_attr($magazine_express_theme_color_one).';
		}

		.sticky .entry-title::before,.sidebar h5,#button,.post-navigation .nav-previous a:hover, .post-navigation .nav-next a:hover, .posts-navigation .nav-previous a:hover, .posts-navigation .nav-next a:hover,.serach_inner [type="submit"],.main-navigation .sub-menu,.comment-respond input#submit,.woocommerce .woocommerce-ordering select,.pro-button a, .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt,.slide-btn a:hover,.wp-block-button__link,.woocommerce-account .woocommerce-MyAccount-navigation ul li{
			background: '.esc_attr($magazine_express_theme_color_two).';
		}
		.main-navigation .menu > li > a:hover,.sidebar ul li a:hover,p.price, .woocommerce ul.products li.product .price, .woocommerce div.product p.price, .woocommerce div.product span.price,.woocommerce-message::before, .woocommerce-info::before,.top-info strong,.subscribe-btn a,.slide-btn a,#featured-topic h3{
			color: '.esc_attr($magazine_express_theme_color_two).';
		}
		.woocommerce-message, .woocommerce-info,.post-navigation .nav-previous a:hover, .post-navigation .nav-next a:hover, .posts-navigation .nav-previous a:hover, .posts-navigation .nav-next a:hover{
			border-color: '.esc_attr($magazine_express_theme_color_two).';
		}
	';
    wp_add_inline_style( 'magazine-express-style',$theme_color_css );	

}
add_action( 'wp_enqueue_scripts', 'magazine_express_theme_color' );

/**
 * Enqueue S Header.
 */
function magazine_express_sticky_header() {

  $magazine_express_sticky_header = get_theme_mod('magazine_express_sticky_header');

  $magazine_express_custom_style= "";

  if($magazine_express_sticky_header != true){

    $magazine_express_custom_style .='.stick_header{';

      $magazine_express_custom_style .='position: static;';
      
    $magazine_express_custom_style .='}';
  } 

  wp_add_inline_style( 'magazine-express-style',$magazine_express_custom_style );

}
add_action( 'wp_enqueue_scripts', 'magazine_express_sticky_header' );

function magazine_express_font_url(){
	$font_url = '';
	$Poppins = _x('on','Poppins:on or off','magazine-express');
	
	if('off' !== $Poppins ){
		$font_family = array();
		if('off' !== $Poppins){
			$font_family[] = 'Poppins:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900';
		}
		$query_args = array(
			'family'	=> urlencode(implode('|',$font_family)),
		);
		$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	}
	return $font_url;
}

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/*dropdown page sanitization*/
function magazine_express_sanitize_dropdown_pages( $page_id, $setting ) {
	$page_id = absint( $page_id );
	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

function magazine_express_string_limit_words($string, $word_limit) {
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit)
	array_pop($words);
	return implode(' ', $words);
}

/*radio button sanitization*/
function magazine_express_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}
/*checkbox sanitization*/
function magazine_express_sanitize_checkbox( $input ) {
  // Boolean check 
  return ( ( isset( $input ) && true == $input ) ? true : false );
}